@@ -2,7 +2,6 @@ import json
 from unittest.mock import patch
 
 import pytest
-from pydantic import ValidationError
 from tornado.httpclient import HTTPClientError
 
 from jupyter_scheduler.exceptions import (
@@ -21,6 +20,7 @@ from jupyter_scheduler.models import (
     Status,
     UpdateJob,
 )
+from jupyter_scheduler.pydantic_v1 import ValidationError
 from jupyter_scheduler.tests.utils import expected_http_error
 
 
