@@ -3,7 +3,7 @@ import React, { ChangeEvent } from 'react';
 import { FormControlLabel, InputLabel, Radio, RadioGroup } from '@mui/material';
 import Stack from '@mui/system/Stack';
 
-import { useTranslator } from '../hooks';
+import { useEventLogger, useTranslator } from '../hooks';
 import { ICreateJobModel } from '../model';
 import { ScheduleInputs } from './schedule-inputs';
 import { Scheduler } from '../tokens';
@@ -26,10 +26,15 @@ export function CreateScheduleOptions(
 
   const labelId = `${props.id}-label`;
 
+  const log = useEventLogger();
+
   const handleScheduleOptionsChange = (
     event: ChangeEvent<HTMLInputElement>,
     value: string
   ) => {
+    log(
+      `create-job.job-type.${value === 'Job' ? 'run-now' : 'run-on-schedule'}`
+    );
     const name = event.target.name;
     props.handleModelChange({ ...props.model, [name]: value });
   };
