@@ -1,16 +1,18 @@
 import React from 'react';
 
 import { Scheduler } from '../handler';
-import { useTranslator } from '../hooks';
+import { useEventLogger, useTranslator } from '../hooks';
 
 import { JupyterFrontEnd } from '@jupyterlab/application';
 
 import { Link } from '@mui/material';
+import { FilesDirectoryLink } from './files-directory-link';
 
 export interface IJobFileLinkProps {
   jobFile: Scheduler.IJobFile;
   app: JupyterFrontEnd;
   children?: React.ReactNode;
+  parentComponentName?: string;
 }
 
 export function JobFileLink(props: IJobFileLinkProps): JSX.Element | null {
@@ -20,6 +22,8 @@ export function JobFileLink(props: IJobFileLinkProps): JSX.Element | null {
     return null;
   }
 
+  const log = useEventLogger();
+
   const fileBaseName = props.jobFile.file_path.split('/').pop();
 
   const title =
@@ -27,6 +31,9 @@ export function JobFileLink(props: IJobFileLinkProps): JSX.Element | null {
       ? trans.__('Open input file "%1"', fileBaseName)
       : trans.__('Open output file "%1"', fileBaseName);
 
+  if (props.jobFile.file_format === 'files') {
+    return <FilesDirectoryLink jobFile={props.jobFile} app={props.app} />;
+  }
   return (
     <Link
       key={props.jobFile.file_format}
@@ -38,6 +45,15 @@ export function JobFileLink(props: IJobFileLinkProps): JSX.Element | null {
           | React.MouseEvent<HTMLAnchorElement, MouseEvent>
       ) => {
         e.preventDefault();
+        if (props.parentComponentName) {
+          log(
+            `${props.parentComponentName}.${
+              props.jobFile.file_format === 'input'
+                ? 'open-input-file'
+                : 'open-output-file'
+            }`
+          );
+        }
         props.app.commands.execute('docmanager:open', {
           path: props.jobFile.file_path
         });
