@@ -5,17 +5,19 @@ import { ConfirmDeleteButton, ConfirmButton } from './confirm-buttons';
 import { JobFileLink } from './job-file-link';
 import { CommandIDs } from '..';
 import { Scheduler } from '../handler';
-import { useTranslator } from '../hooks';
+import { useEventLogger, useTranslator } from '../hooks';
 import { ICreateJobModel } from '../model';
 import DownloadIcon from '@mui/icons-material/Download';
 import StopIcon from '@mui/icons-material/Stop';
 import { IconButton, Stack, Link, TableCell, TableRow } from '@mui/material';
+import { getErrorMessage } from '../util/errors';
 
 function StopButton(props: {
   job: Scheduler.IDescribeJob;
   clickHandler: () => void;
 }): JSX.Element | null {
   const trans = useTranslator('jupyterlab');
+  const log = useEventLogger();
   const buttonTitle = props.job.name
     ? trans.__('Stop "%1"', props.job.name)
     : trans.__('Stop job');
@@ -26,7 +28,10 @@ function StopButton(props: {
     >
       <ConfirmButton
         name={buttonTitle}
-        onConfirm={props.clickHandler}
+        onConfirm={() => {
+          log('job-list.stop-confirm');
+          props.clickHandler();
+        }}
         confirmationText={trans.__('Stop')}
         icon={<StopIcon fontSize="small" />}
         remainAfterConfirmation
@@ -60,7 +65,11 @@ function JobFiles(props: {
       {props.job.job_files
         .filter(jobFile => jobFile.file_format !== 'input' && jobFile.file_path)
         .map(jobFile => (
-          <JobFileLink jobFile={jobFile} app={props.app} />
+          <JobFileLink
+            jobFile={jobFile}
+            app={props.app}
+            parentComponentName="jobs-list"
+          />
         ))}
     </>
   );
@@ -76,14 +85,16 @@ type DownloadFilesButtonProps = {
 function DownloadFilesButton(props: DownloadFilesButtonProps) {
   const [downloading, setDownloading] = useState(false);
   const trans = useTranslator('jupyterlab');
+  const log = useEventLogger();
 
   return (
     <IconButton
       aria-label="download"
-      title={trans.__('Download job files for "%1"', props.job.name)}
+      title={trans.__('Download output files for "%1"', props.job.name)}
       disabled={downloading}
       onClick={async () => {
         setDownloading(true);
+        log('jobs-list.download');
         props.app.commands
           .execute(CommandIDs.downloadFiles, {
             id: props.job.job_id,
@@ -91,12 +102,14 @@ function DownloadFilesButton(props: DownloadFilesButtonProps) {
           })
           .then(_ =>
             new Promise(res => setTimeout(res, 5000)).then(_ => {
+              log('jobs-list.download');
               setDownloading(false);
               props.reload();
             })
           )
-          .catch((e: Error) => {
-            props.setDisplayError(e.message);
+          .catch((e: unknown) => {
+            const message = getErrorMessage(e);
+            props.setDisplayError(message);
           });
       }}
     >
@@ -120,16 +133,24 @@ export function buildJobRow(
     jobFile => jobFile.file_format === 'input' && jobFile.file_path
   );
   const trans = useTranslator('jupyterlab');
+  const log = useEventLogger();
 
   const cellContents: React.ReactNode[] = [
     <Link
-      onClick={() => showDetailView(job.job_id)}
+      onClick={() => {
+        log('jobs-list.open-detail');
+        showDetailView(job.job_id);
+      }}
       title={trans.__('Open detail view for "%1"', job.name)}
     >
       {job.name}
     </Link>,
     inputFile ? (
-      <JobFileLink app={app} jobFile={inputFile}>
+      <JobFileLink
+        app={app}
+        jobFile={inputFile}
+        parentComponentName="jobs-list"
+      >
         {job.input_filename}
       </JobFileLink>
     ) : (
@@ -153,23 +174,31 @@ export function buildJobRow(
       <ConfirmDeleteButton
         name={job.name}
         clickHandler={() => {
+          log('jobs-list.delete');
           app.commands
             .execute(CommandIDs.deleteJob, {
               id: job.job_id
             })
             .then(_ => deleteRow(job.job_id))
-            .catch((e: Error) => setDisplayError(e.message));
+            .catch((e: unknown) => {
+              const message = getErrorMessage(e);
+              setDisplayError(message);
+            });
         }}
       />
       <StopButton
         job={job}
-        clickHandler={() =>
+        clickHandler={() => {
+          log('jobs-list.stop');
           app.commands
             .execute(CommandIDs.stopJob, {
               id: job.job_id
             })
-            .catch((e: Error) => setDisplayError(e.message))
-        }
+            .catch((e: unknown) => {
+              const message = getErrorMessage(e);
+              setDisplayError(message);
+            });
+        }}
       />
     </Stack>
   ];
