@@ -17,7 +17,7 @@ import {
 } from '../components/output-format-picker';
 import { ParametersPicker } from '../components/parameters-picker';
 import { Scheduler, SchedulerService } from '../handler';
-import { useTranslator } from '../hooks';
+import { useEventLogger, useTranslator } from '../hooks';
 import { ICreateJobModel, IJobParameter, JobsView } from '../model';
 import { Scheduler as SchedulerTokens } from '../tokens';
 import { NameError } from '../util/job-name-validation';
@@ -41,6 +41,8 @@ import {
 } from '@mui/material';
 
 import { Box, Stack } from '@mui/system';
+import { getErrorMessage } from '../util/errors';
+import { PackageInputFolderControl } from '../components/input-folder-checkbox';
 
 export interface ICreateJobProps {
   model: ICreateJobModel;
@@ -319,7 +321,8 @@ export function CreateJob(props: ICreateJobProps): JSX.Element {
       compute_type: props.model.computeType,
       idempotency_token: props.model.idempotencyToken,
       tags: props.model.tags,
-      runtime_environment_parameters: props.model.runtimeEnvironmentParameters
+      runtime_environment_parameters: props.model.runtimeEnvironmentParameters,
+      package_input_folder: props.model.packageInputFolder
     };
 
     if (props.model.parameters !== undefined) {
@@ -335,13 +338,16 @@ export function CreateJob(props: ICreateJobProps): JSX.Element {
     api
       .createJob(jobOptions)
       .then(response => {
+        log('create-job.create-job.success');
         // Switch to the list view with "Job List" active
         props.showListView(JobsView.ListJobs, response.job_id, jobOptions.name);
       })
-      .catch((error: Error) => {
+      .catch((e: unknown) => {
+        const detail = getErrorMessage(e);
+        log('create-job.create-job.failure', detail);
         props.handleModelChange({
           ...props.model,
-          createError: error.message,
+          createError: detail,
           createInProgress: false
         });
       });
@@ -364,7 +370,8 @@ export function CreateJob(props: ICreateJobProps): JSX.Element {
       tags: props.model.tags,
       runtime_environment_parameters: props.model.runtimeEnvironmentParameters,
       schedule: props.model.schedule,
-      timezone: props.model.timezone
+      timezone: props.model.timezone,
+      package_input_folder: props.model.packageInputFolder
     };
 
     if (props.model.parameters !== undefined) {
@@ -382,6 +389,7 @@ export function CreateJob(props: ICreateJobProps): JSX.Element {
     api
       .createJobDefinition(jobDefinitionOptions)
       .then(response => {
+        log('create-job.create-job-definition.success');
         // Switch to the list view with "Job Definition List" active
         props.showListView(
           JobsView.ListJobDefinitions,
@@ -389,10 +397,12 @@ export function CreateJob(props: ICreateJobProps): JSX.Element {
           jobDefinitionOptions.name
         );
       })
-      .catch((error: Error) => {
+      .catch((e: unknown) => {
+        const detail = getErrorMessage(e);
+        log('create-job.create-job-definition.failure', detail);
         props.handleModelChange({
           ...props.model,
-          createError: error.message,
+          createError: detail,
           createInProgress: false
         });
       });
@@ -451,6 +461,8 @@ export function CreateJob(props: ICreateJobProps): JSX.Element {
   // Does the currently-selected environment accept times in UTC only?
   const utcOnly = envsByName[props.model.environment]?.utc_only;
 
+  const log = useEventLogger();
+
   return (
     <Box sx={{ p: 4 }}>
       <form className={`${formPrefix}form`} onSubmit={e => e.preventDefault()}>
@@ -495,6 +507,10 @@ export function CreateJob(props: ICreateJobProps): JSX.Element {
             environmentList={environmentList}
             value={props.model.environment}
           />
+          <PackageInputFolderControl
+            onChange={handleInputChange}
+            inputFile={props.model.inputFile}
+          />
           <OutputFormatPicker
             label={trans.__('Output formats')}
             name="outputFormat"
@@ -528,9 +544,14 @@ export function CreateJob(props: ICreateJobProps): JSX.Element {
           <Accordion
             defaultExpanded={false}
             expanded={advancedOptionsExpanded}
-            onChange={(_: React.SyntheticEvent, expanded: boolean) =>
-              setAdvancedOptionsExpanded(expanded)
-            }
+            onChange={(e: React.SyntheticEvent, expanded: boolean) => {
+              log(
+                `create-job.advanced-options.${
+                  expanded ? 'expand' : 'collapse'
+                }`
+              );
+              setAdvancedOptionsExpanded(expanded);
+            }}
           >
             <AccordionSummary
               expandIcon={<caretDownIcon.react />}
@@ -573,7 +594,10 @@ export function CreateJob(props: ICreateJobProps): JSX.Element {
               <>
                 <Button
                   variant="outlined"
-                  onClick={e => props.showListView(JobsView.ListJobs)}
+                  onClick={e => {
+                    log('create-job.cancel');
+                    props.showListView(JobsView.ListJobs);
+                  }}
                 >
                   {trans.__('Cancel')}
                 </Button>
@@ -581,6 +605,11 @@ export function CreateJob(props: ICreateJobProps): JSX.Element {
                 <Button
                   variant="contained"
                   onClick={(e: React.MouseEvent) => {
+                    const eventType =
+                      props.model.createType === 'Job'
+                        ? 'create-job'
+                        : 'create-job-definition';
+                    log(`create-job.${eventType}`);
                     submitForm(e);
                     return false;
                   }}
